package com.ruoyi.project.pssr.service;

import java.util.List;
import com.ruoyi.project.pssr.domain.TPssrFile;

/**
 * PSSR附件Service接口
 * 
 * @author ssy
 * @date 2024-10-30
 */
public interface ITPssrFileService 
{
    /**
     * 查询PSSR附件
     * 
     * @param fileId PSSR附件ID
     * @return PSSR附件
     */
    public TPssrFile selectTPssrFileById(Long fileId);

    /**
     * 查询PSSR附件列表
     * 
     * @param tPssrFile PSSR附件
     * @return PSSR附件集合
     */
    public List<TPssrFile> selectTPssrFileList(TPssrFile tPssrFile);
    public List<TPssrFile> selectTPssrFileListByItem(Long subId,Long itemId, String forShort);

    /**
     * 新增PSSR附件
     * 
     * @param tPssrFile PSSR附件
     * @return 结果
     */
    public int insertTPssrFile(TPssrFile tPssrFile);

    /**
     * 修改PSSR附件
     * 
     * @param tPssrFile PSSR附件
     * @return 结果
     */
    public int updateTPssrFile(TPssrFile tPssrFile);

    /**
     * 批量删除PSSR附件
     * 
     * @param fileIds 需要删除的PSSR附件ID
     * @return 结果
     */
    public int deleteTPssrFileByIds(Long[] fileIds);

    /**
     * 删除PSSR附件信息
     * 
     * @param fileId PSSR附件ID
     * @return 结果
     */
    public int deleteTPssrFileById(Long fileId);

    public void updateFileRelevance(List<Long> fileIds,String forShort,Long itemId,Long subId);
}
